==> JavaScriptCore-417.11.tar.gz: JavaScriptCore-417.11/bindings/jni/jni_instance.h <==
/*
 * Copyright (C) 2003 Apple Computer, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
#ifndef _JNI_INSTANCE_H_
#define _JNI_INSTANCE_H_

#include <CoreFoundation/CoreFoundation.h>

#include <JavaVM/jni.h>

#include <JavaScriptCore/runtime.h>

namespace KJS {

namespace Bindings {

class JavaClass;

class JObjectWrapper
{
friend class JavaArray;
friend class JavaInstance;
friend class JavaMethod;

protected:
    JObjectWrapper(jobject instance);    
    void ref() { _ref++; }
    void deref() { 
        _ref--;
        if (_ref == 0)
            delete this;
    }
    
    ~JObjectWrapper();
	
    jobject _instance;

private:
    JNIEnv *_env;
    unsigned int _ref;
};

class JavaInstance : public Instance
{
public:
    JavaInstance (jobject instance, const RootObject *r);
        
    ~JavaInstance ();
    
    virtual Class *getClass() const;
    
    virtual void begin();
    virtual void end();
    
    virtual Value valueOf() const;
    virtual Value defaultValue (Type hint) const;

    virtual Value invokeMethod (ExecState *exec, const MethodList &method, const List &args);
    virtual Value invokeDefaultMethod (ExecState *exec, const List &args);

    jobject javaInstance() const { return _instance->_instance; }
    
    Value stringValue() const;
    Value numberValue() const;
    Value booleanValue() const;
        
private:
    JavaInstance ();                         // prevent default construction
    JavaInstance (JavaInstance &);           // prevent copying
    JavaInstance &operator=(JavaInstance &); // prevent copying
    
    JObjectWrapper *_instance;
    mutable JavaClass *_class;
};

} // namespace Bindings

} // namespace KJS

#endif

==> JavaScriptCore-418.3.tar.gz: JavaScriptCore-418.3/bindings/jni/jni_instance.h <==
/*
 * Copyright (C) 2003 Apple Computer, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
#ifndef _JNI_INSTANCE_H_
#define _JNI_INSTANCE_H_

#include <CoreFoundation/CoreFoundation.h>

#include <JavaVM/jni.h>

#include <JavaScriptCore/runtime.h>
#include "shared_ptr.h"

namespace KJS {

namespace Bindings {

class JavaClass;

class JObjectWrapper
{
friend class SharedPtr<JObjectWrapper>;
friend class JavaArray;
friend class JavaInstance;
friend class JavaMethod;

protected:
    JObjectWrapper(jobject instance);    
    ~JObjectWrapper();
    
    void ref() { _refCount++; }
    void deref() 
    { 
        if (--_refCount == 0) 
            delete this; 
    }
	
    jobject _instance;

private:
    JNIEnv *_env;
    unsigned int _refCount;
};

class JavaInstance : public Instance
{
public:
    JavaInstance (jobject instance, const RootObject *r);
        
    ~JavaInstance ();
    
    virtual Class *getClass() const;
    
    virtual void begin();
    virtual void end();
    
    virtual Value valueOf() const;
    virtual Value defaultValue (Type hint) const;

    virtual Value invokeMethod (ExecState *exec, const MethodList &method, const List &args);
    virtual Value invokeDefaultMethod (ExecState *exec, const List &args);

    jobject javaInstance() const { return _instance->_instance; }
    
    Value stringValue() const;
    Value numberValue() const;
    Value booleanValue() const;
        
private:
    JavaInstance ();                         // prevent default construction
    JavaInstance (JavaInstance &);           // prevent copying
    JavaInstance &operator=(JavaInstance &); // prevent copying
    
    SharedPtr<JObjectWrapper> _instance;
    mutable JavaClass *_class;
};

} // namespace Bindings

} // namespace KJS

#endif
